@@ -31,7 +31,7 @@ import clam.common.status
 import clam.common.parameters
 import clam.common.formats
 
-os.environ['PYTHONPATH'] = '/var/www/lib/python2.6/site-packages/frog' #Necessary for University of Tilburg servers (change or remove this in your own setup)
+
 
 #this script takes three arguments: $DATAFILE $STATUSFILE $OUTPUTDIRECTORY
 bindir = sys.argv[1]
@@ -39,6 +39,9 @@ datafile = sys.argv[2]
 statusfile = sys.argv[3]
 outputdir = sys.argv[4]
 
+
+os.environ['PYTHONPATH'] = bindir + '/../lib/python' + str(sys.version_info.major) + '.' + str(sys.version_info.minor) + '/site-packages/frog' #Necessary for University of Tilburg servers (change or remove this in your own setup)
+
 #Obtain all data from the CLAM system (passed in $DATAFILE (clam.xml))
 clamdata = clam.common.data.getclamdata(datafile)
 
@@ -77,7 +80,7 @@ for i, inputfile in enumerate(clamdata.inputfiles('maininput')):
         docid = 'untitled'
         
     print >>sys.stderr,"Invoking Frog"          
-    r = os.system(bindir + "frog -c /var/www/etc/frog/frog.cfg " + cmdoptions + " -t " + str(inputfile) + " --id='" + docid + "' -X '" + outputdir + outputstem + ".xml' -o '" + outputdir + outputstem + ".frog.out'")                    
+    r = os.system(bindir + "frog -c " + bindir + "../etc/frog/frog.cfg " + cmdoptions + " -t " + str(inputfile) + " --id='" + docid + "' -X '" + outputdir + outputstem + ".xml' -o '" + outputdir + outputstem + ".frog.out'")                    
     if (r != 0):
         clam.common.status.write(statusfile, "Frog returned with an error whilst processing " + os.path.basename(str(inputfile) + " (plain text). Aborting"),100)
         sys.exit(1)
